package com.caimei.service.impl;

import com.caimei.mapper.VideoMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.VideoPo;
import com.caimei.model.vo.VideoVo;
import com.caimei.service.SDKService;
import com.caimei.service.VideoService;
import com.caimei.utils.CodeUtil;
import com.caimei.utils.SHA1;
import com.caimei.utils.WxUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/14
 */
@Slf4j
@Service
public class SDKServiceImpl implements SDKService {

    @Override
    public ResponseJson<Map<String, String>> getConfigData(String appId, String appSecret, String url) {
        if (StringUtils.isEmpty(appId)) {
            return ResponseJson.error("参数异常，请输入appId", null);
        }
        if (StringUtils.isEmpty(appSecret)) {
            return ResponseJson.error("参数异常，请输入appSecret", null);
        }
        if (StringUtils.isEmpty(url)) {
            return ResponseJson.error("参数异常，请输入url", null);
        }
        // 获取accessToken
        String accessToken = WxUtils.getAccessToken(appId, appSecret);
        // 获取jsapiTicket
        Map<String, String> ticketMap = WxUtils.getJsapiTicket(accessToken);
        String ticket = ticketMap.get("ticket");
        // 生成noncestr(随机字符串)和timestamp(时间戳)
        String noncestr = CodeUtil.getRandomCharAndNumr(8);
        String timestamp = String.valueOf(System.currentTimeMillis() / 1000);
        String signStr = "jsapi_ticket=" + ticket + "&noncestr=" + noncestr + "&timestamp=" + timestamp + "&url=" + url;
        String signature = SHA1.getSHA1(signStr);
        Map<String, String> map = new HashMap<>(5);
        map.put("timestamp", timestamp);
        map.put("accessToken", accessToken);
        map.put("ticket", ticket);
        map.put("noncestr", noncestr);
        map.put("signature", signature);
        return ResponseJson.success(map);
    }
}
