package com.caimei.utils;


import com.alibaba.fastjson.JSONObject;
import com.aliyun.opensearch.sdk.dependencies.org.apache.http.client.HttpClient;
import com.aliyun.opensearch.sdk.dependencies.org.apache.http.client.ResponseHandler;
import com.aliyun.opensearch.sdk.dependencies.org.apache.http.client.methods.HttpGet;
import com.aliyun.opensearch.sdk.dependencies.org.apache.http.impl.client.BasicResponseHandler;
import com.aliyun.opensearch.sdk.dependencies.org.apache.http.impl.client.DefaultHttpClient;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Aslee
 * @date   2021/7/14
 */
public class WxUtils {
	public final static String GET_TOKEN_URL = "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=APPID&secret=SECRET";
    public final static String GET_TICKET_URL = "https://api.weixin.qq.com/cgi-bin/ticket/getticket?access_token=ACCESS_TOKEN&type=jsapi";

    /**
     * 获取accessToken
     * @param appId         公众号appId
     * @param appSecret     公众号appSecret
     * @return
     */
	public static String getAccessToken(String appId,String appSecret){
		String requestUrl = GET_TOKEN_URL.replace("APPID", appId).replace("SECRET", appSecret);
		HttpClient client = null;
		String accessToken = null;
		try {
            client = new DefaultHttpClient();
            HttpGet httpget = new HttpGet(requestUrl);
			ResponseHandler<String> responseHandler = new BasicResponseHandler();
			String response = client.execute(httpget, responseHandler);
			JSONObject tokenJson = JSONObject.parseObject(response);
			accessToken = String.valueOf(tokenJson.get("access_token"));
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			client.getConnectionManager().shutdown();
		}
		return accessToken;
	}

    /**
     * 获取jsapi_ticket
     * @param accessToken   accessToken
     * @return
     */
	public static Map<String,String> getJsapiTicket(String accessToken){
        String requestUrl = GET_TICKET_URL.replace("ACCESS_TOKEN", accessToken);
        HttpClient client = null;
        Map<String, String> result = new HashMap<String, String>();
        try {
            client = new DefaultHttpClient();
            HttpGet httpget = new HttpGet(requestUrl);
            ResponseHandler<String> responseHandler = new BasicResponseHandler();
            String response = client.execute(httpget, responseHandler);
            JSONObject ticketJson = JSONObject.parseObject(response);
            String errcode = String.valueOf(ticketJson.get("errcode"));
            String errmsg = String.valueOf(ticketJson.get("errmsg"));
            String ticket = String.valueOf(ticketJson.get("ticket"));
            String expiresIn = String.valueOf(ticketJson.get("expires_in"));
            result.put("errcode", errcode);
            result.put("errmsg", errmsg);
            result.put("ticket", ticket);
            result.put("expiresIn", expiresIn);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            client.getConnectionManager().shutdown();
        }
        return result;
    }




}
